==> haskell-optparse-generic-1.4.4-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optparse-generic
version:              1.4.4
visibility:           public
id:                   optparse-generic-1.4.4-3nBGpWbJUHh9GCbVv3YAL8
key:                  optparse-generic-1.4.4-3nBGpWbJUHh9GCbVv3YAL8
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.

    See the documentation in "Options.Generic" for an example of how to use
    this library

category:             System
abi:                  7b3ccc046b5fd4f3e3c534b54609a0ad
exposed:              True
exposed-modules:      Options.Generic
import-dirs:          /usr/lib/ghc-8.10.3/site-local/optparse-generic-1.4.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/optparse-generic-1.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/optparse-generic-1.4.4
hs-libraries:         HSoptparse-generic-1.4.4-3nBGpWbJUHh9GCbVv3YAL8
depends:
    Only-0.1-Hmiu2AVa9qJ6EI7MrgJvvl base-4.14.1.0 bytestring-0.10.12.0
    optparse-applicative-0.16.1.0-DSn4p6wqAGaKlKtpFUzeCK
    system-filepath-0.4.14-3jRmlRAmoRe4W3Q3diL3e3 text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2 void-0.7.3-FJLCa6y31Qt20kSi8TCcBC

haddock-interfaces:
    /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock

haddock-html:         /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-generic-1.4.4-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optparse-generic
version:              1.4.4
visibility:           public
id:                   optparse-generic-1.4.4-GJ6TGEb0RAE49Hs9nNodJx
key:                  optparse-generic-1.4.4-GJ6TGEb0RAE49Hs9nNodJx
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.

    See the documentation in "Options.Generic" for an example of how to use
    this library

category:             System
abi:                  9173b922bc51b8d3913affa4da3c4030
exposed:              True
exposed-modules:      Options.Generic
import-dirs:          /usr/lib/ghc-8.10.3/site-local/optparse-generic-1.4.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/optparse-generic-1.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/optparse-generic-1.4.4
hs-libraries:         HSoptparse-generic-1.4.4-GJ6TGEb0RAE49Hs9nNodJx
depends:
    Only-0.1-Hmiu2AVa9qJ6EI7MrgJvvl base-4.14.1.0 bytestring-0.10.12.0
    optparse-applicative-0.16.1.0-4brr8IFRrPZ2CqGdAfEYK7
    system-filepath-0.4.14-AncElNDaNb7DrbfXq2rUst text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2 void-0.7.3-FJLCa6y31Qt20kSi8TCcBC

haddock-interfaces:
    /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock

haddock-html:         /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
